@@ -186,13 +186,22 @@ void on_menu_quit(GtkMenuItem * menuitem, UIComponents *uic) {
 }
 
 void on_menu_about(GtkMenuItem * menuitem, UIComponents *uic) {
+	gchar **authors = g_strsplit("Fred Lef\xc3\xa9v\xc3\xa8re-Laoide\n", "\n", -1);
+	GdkPixbuf *logo = gdk_pixbuf_new_from_file(ICONFILE, NULL);
+	gchar *comment = g_strdup_printf("Gnokii Compile : %x\nGnokii Runtime : %x", LIBGNOKII_VERSION,gn_lib_version());
 	gtk_show_about_dialog(GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(menuitem))),
 		"version", VERSION,
 		"website", "https://garage.maemo.org/projects/phonelink/",
 		"website-label", _("Garage Page @ Maemo"),
-		"authors", g_strsplit("Fred Lef\xc3\xa9v\xc3\xa8re-Laoide\n", "\n", -1),
-		"logo", gdk_pixbuf_new_from_file(ICONFILE, NULL),
+		"authors", authors,
+		"logo", logo,
+		"comments", comment,
 		NULL);
+	g_strfreev(authors);
+	/*
+	gdk_pixbuf_free(logo);
+	*/
+	g_free(comment);
 }
 
 void on_menu_transform(GtkCheckMenuItem *checkMenuitem, UIComponents *uic) {
